@@ -46,18 +46,27 @@ class LightManager(serial.Serial):
 
     def switch_off(self) -> None:
         """
-        Switch off the five lights in the platform
+        Switch off all lights in the platform
         """
         for c in self.list_channels:
             command = compute_command(intensity=0, channel=c)
             self.write(command.encode())
 
-    def switch_on(self, list_intensity) -> None:
+    def switch_on(self, intensities, channels=None) -> None:
         """
-        Switch on the lights sending 5 commands of intensity for the five lights
-        :param list_intensity: list of the light's intensity with index respective to the channel list
+        Switch on one or several lights sending several commands of intensity for the lights
+        :param channels: channels of the lights which change value
+        :param intensities: list of the light's intensity with index respective to the channel list
         """
-        for c, i in zip(self.list_channels, list_intensity):
-            command = compute_command(intensity=i, channel=c)
+        if channels is None:
+            channels = self.list_channels
+
+        if isinstance(channels, list):
+            for c, i in zip(channels, intensities):
+                command = compute_command(intensity=i, channel=c)
+                self.write(command.encode())
+
+        elif isinstance(channels, int):
+            command = compute_command(intensity=intensities, channel=channels)
             self.write(command.encode())
 
